#include <detect.h>

/*----------------------------------------------------------------------*
 *	Function: BOOL Fnull(points,lookback,data) - Null filter	*
 *----------------------------------------------------------------------*
 *	Arguments:	LONG points - number of data points		*
 *			LONG lookback - amount of lookback present	*
 *			LONG *data - data array in question 		*
 *----------------------------------------------------------------------*
 *	Returns:	Returns TRUE if job completed sucessfully	*
 *----------------------------------------------------------------------*
 *	Lookback:	This filter requires no lookback		*
 *----------------------------------------------------------------------*
 *	This routine processes the current record, which has "points"	*
 *	seismic samples, with an FIR filter.  The array "data" 		*
 *	contains these samples plus the last "lookback" values from	*
 *	the previous record (the values from the previous record,	*
 *	that are needed for the FIR filter, are stored in the 0th	*
 *	through lookback-1 positions of the array).  Hence, upon	*
 *	input, the first sample of the current record is stored at	*
 *	index "lookback" of the array.  				*
 *									*
 *	To conserve RAM, we use the same array (the array "data")	*
 *	for both input to the filter and output of it:  Each time	*
 *	we process a new sample, a slot is free above the lookback	*
 *	area.  We fill this slot with the filtered data; hence,		*
 *	when the record has been completely processed, the first	*
 *	"points" slots of the array contain the filtered seismic	*
 *	samples of the record.						*
 *----------------------------------------------------------------------*
 *	The Fnull() filter is used when a lookback has been used,	*
 *	but no filtering is desired.  Fnull() simply rolls the data	*
 *	into place for detection and does not otherwise process it.	*
 *----------------------------------------------------------------------*/

BOOL Fnull(point,lookback,data)
LONG point,lookback;
LONG *data;
{

	LONG *ldp,result;
	LONG i;

	ldp= &data[lookback];

	for (i=0; i<point; i++) {

		result= *ldp;
		ldp++;

		data[i]=result;

	}

	return(TRUE);

}
