#ifndef SLOPEMONITOR_HH
#define SLOPEMONITOR_HH

#include "DatEnv.hh"
#include "Complex.hh"
#include "MonServer.hh"         /* send data to dmt viewer */
#include "TrigClient.hh"        /* write triggers */
#include "SlopeFilter.hh"
#include "Event.hh"
#include "TransientLeague.hh"
#include "IIRFilter.hh"
#include "DecimateBy2.hh"

class ostream;

namespace xsil {
  class Xwriter;
}
//
//    Data Monitor template class.
//    Class DatTemplate inherits member functions both from
//    Class DatEnv and from Class MonServer
//
// class SlopeMonitor : public DatEnv , public TrigClient  {
class SlopeMonitor : public DatEnv , public MonServer, public TrigClient  {
  //class SlopeMonitor : public DatEnv , public MonServer {
public:
  int MaxFrame;               //  Number of frames I should process
  
  SlopeMonitor(int argc, const char *argv[]);  // Constructor
  ~SlopeMonitor();                             // Destructor
  void ProcessData(void);
  void DumpHelp(void);
  void GetEllip(dComplex*,dComplex*,double*);
  void GetResGain(dComplex*, dComplex* ,double*);
  void GetAsqResGain(dComplex*, dComplex* ,double*);
  // these filters are intended for the S1 run transient hisogram
  // generators. Ed Daw, 20th June 2002
  void GetSixtyfive(dComplex*, dComplex* ,double*);
  void GetTwohundred(dComplex*, dComplex* ,double*);
  void GetSixfifty(dComplex*, dComplex* ,double*);
  void GetTwothousand(dComplex*, dComplex* ,double*);
  // the Attention function is only needed if you want to write
  // data to the DMT monitor viewer
  void Attention(void);
private:
  // slope filter
  // SlopeFilter sf;
  // transient league
  TransientLeague transient_store;
  IIRFilter myiir;
  SlopeFilter slfilt;
  DecimateBy2 mydecimate;
  bool last_data_ok;
  char filepath[100];
  char full_filename[150];
  int league_time_secs;
  char channelname[100];
  char filttype[20];
  int no_of_transients;
  int peak_width_bins;
  double filter_gain;
  float tldur; // duration of transient league in seconds
  float pkdur; // expected peak duration in seconds
  int peakspersegment; // number of peaks fitting in a data segment
                                // acquired during a single monitor data
                                // processing iteration
  int binsperpeak; // number of bins fitting under peak. 
  double target_sampling_period;
  double target_sampling_rate;
  double data_segment_duration;
  double transient_league_duration;
  TSeries** filteredEvent;
  int ndecstages;
  int peak_nbins;
  bool write_event_segment; // if yes, event file contains a time segment
  std::string monserver_name;
};

#endif     //  LINEMONITOREX_HH













