#ifndef RECTANGLEH
#define RECTANGLEH

#include <TidEvent.h>
#include <list>
#include <stdio.h>

//For Rectangle:
  // 0: low time black
  // 1: high time black
  // 2: low freq black
  // 3: high freq b
  // 4: low time white
  // 5: high t w
  // 6: low freq w
  // 7: high f w

typedef std::vector<double> VectorDouble;

class TidRectangle : public TidEvent {
  
  double TimeResolution;

  std::vector<bool> SlicesDefined;
  std::vector<double> lastCost;
  std::vector<double> firstWhite,
    firstBlack,
    oalastBlack; // one after last black

  std::vector<VectorDouble> paramOpti;

 public:

  TidRectangle(double T, double alpha_, unsigned int argc, 
	       std::vector<std::string>& argv) 
    : TidEvent(alpha_,argc,argv) {TimeResolution = T;};

  double CostFunction(ArrayBool *, std::vector<double>*);

  void Delete(ArrayBool*, std::vector<double>*);

  double Area(std::vector<double>*, double);

  void SlicesUndefined ();

  //  void SetMaxT();
};



typedef std::vector<unsigned int> VectorUInt;

class TidCompositeRectangle {

  bool Debug;
  std::string DebugFile;

  bool dFileOpen;
  FILE* dFile;

  std::vector<char> varname;
  std::vector<double> varlb, varub; // lower & upper bounds on variable
  std::vector<double> dvar; // step size

  std::list<VectorUInt> params; 

  unsigned int maxAboveThrStop; // number of points above threshold required to stop an event

  bool inEvent;  
  double minCost;
  unsigned int nAboveThr;
  std::vector<double> varBest;
  double minTime, evDur;



 public:

  std::list<TidRectangle> rectangles;

  TidCompositeRectangle() {Debug=0; maxAboveThrStop=15; inEvent=0; minCost=1E100; nAboveThr=0; minTime=0;};
  ~TidCompositeRectangle();

  //  double Cost(ArrayBool *);

  bool Test(ArrayBool *, double, std::vector<std::string>* params, 
	    double *evDuration, double Time0, double BPP, 
	    bool NormalizeCost = 0); // test & delete; params[0] = cost, params[1] = variable name, params[2] = variable value, ...

  void PushBack(TidRectangle r);

  double GetMaxT();

  void SetmaxAboveThrStop(unsigned int m) { maxAboveThrStop=m; }

  void SetDebug() {Debug=1;}

  void SetDebugFile(std::string file);

  void Dump(FILE *);
};
  
#endif
